==> apache-camel-3.4.5-src.zip: apache-camel-3.4.5/components/camel-pubnub/src/test/java/org/apache/camel/component/pubnub/example/PubNubGeoLocationExample.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.pubnub.example;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.main.Main;

import static org.apache.camel.component.pubnub.example.PubNubExampleConstants.PUBNUB_PUBLISH_KEY;
import static org.apache.camel.component.pubnub.example.PubNubExampleConstants.PUBNUB_SUBSCRIBE_KEY;

/**
 * Example of the use of GeoLocation Blocks https://www.pubnub.com/blocks-catalog/geolocation/
 */

public final class PubNubGeoLocationExample {

    private PubNubGeoLocationExample() {
    }

    public static void main(String[] args) throws Exception {
        Main main = new Main();
        main.configure().addRoutesBuilder(new GeoLocationRoute());
        main.run();
    }

    static class GeoLocationRoute extends RouteBuilder {
        @Override
        public void configure() throws Exception {
            from("timer:geotimer")
                .process(exchange -> exchange.getIn().setBody(new Foo("bar", "TEXT")))
                .to("pubnub:eon-maps-geolocation-input?operation=fire&publishKey=" + PUBNUB_PUBLISH_KEY + "&subscribeKey=" + PUBNUB_SUBSCRIBE_KEY);

            from("pubnub:eon-map-geolocation-output?subscribeKey=" + PUBNUB_SUBSCRIBE_KEY)
                .log("${body}");
        }
    }

    static class Foo {
        String foo;
        String text;

        Foo(String foo, String text) {
            this.foo = foo;
            this.text = text;
        }
    }
}

==> apache-camel-3.20.0-src.zip: apache-camel-3.20.0/components/camel-pubnub/src/test/java/org/apache/camel/component/pubnub/example/PubNubGeoLocationExample.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.pubnub.example;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.main.Main;

import static org.apache.camel.component.pubnub.example.PubNubExampleConstants.PUBNUB_PUBLISH_KEY;
import static org.apache.camel.component.pubnub.example.PubNubExampleConstants.PUBNUB_SUBSCRIBE_KEY;

/**
 * Example of the use of GeoLocation Blocks https://www.pubnub.com/blocks-catalog/geolocation/
 */

public final class PubNubGeoLocationExample {

    private PubNubGeoLocationExample() {
    }

    public static void main(String[] args) throws Exception {
        Main main = new Main();
        main.configure().addRoutesBuilder(new GeoLocationRoute());
        main.run();
    }

    static class GeoLocationRoute extends RouteBuilder {
        @Override
        public void configure() {
            from("timer:geotimer")
                    .process(exchange -> exchange.getIn().setBody(new Foo("bar", "TEXT")))
                    .to("pubnub:eon-maps-geolocation-input?operation=fire&publishKey=" + PUBNUB_PUBLISH_KEY + "&subscribeKey="
                        + PUBNUB_SUBSCRIBE_KEY);

            from("pubnub:eon-map-geolocation-output?subscribeKey=" + PUBNUB_SUBSCRIBE_KEY)
                    .log("${body}");
        }
    }

    static class Foo {
        String foo;
        String text;

        Foo(String foo, String text) {
            this.foo = foo;
            this.text = text;
        }
    }
}
